View source: R/create_template.R
| tidy_purl | R Documentation |
Knits and purls an Rmd file into a format which can be written to an R file.
tidy_purl(params)
params |
vector. Containing file object linking to file to be knitted and a list containing any objects to be knitted into the file. |
Simon E. H. Smart simon.smart@cantab.net
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.